<?php

namespace Drupal\usage_data;

/**
 * Usage Data storage interface.
 */
interface UsageDataStorageInterface {

  /**
   * Records Usage keyed by type.
   *
   * @param array $data
   *   The data to insert.
   */
  public function recordUsage(array $data);

  /**
   * Record typed usage.
   *
   * Inserts are done in a single transaction for performance reasons.
   *
   * @param string $type
   *   The type of usage to store.
   * @param array $data
   *   The data to insert.
   *
   * @return bool
   *   TRUE if the usage has been stored.
   */
  public function recordUsageByType($type, array $data);

  /**
   * Delete usage data from tables.
   *
   * @param int $entityId
   *   The target entity id.
   * @param int $entityTypeId
   *   The target entity type id.
   */
  public function deleteUsageData($entityId, $entityTypeId);

  /**
   * Defines the default schema for usage plugins.
   *
   * @return array
   *   The default schema.
   */
  public function defaultSchema();

  /**
   * Creates a table by type.
   *
   * @param string $type
   *   The type of usage.
   */
  public function createTable($type);

  /**
   * Drops a table by type.
   *
   * @param string $type
   *   The type of usage.
   */
  public function dropTable($type);

}
